==> ansela_0.7-3.tar.gz: ansela-0.7/src/opt/anselA/core/config.py <==
from ConfigParser import ConfigParser
from core import *

def ReadConfig(self):
#    try:
#        configParser.ConfigParser()
#        config.read('ansel-a.cfg')
#
#        # getfloat() raises an exception if the value is not a float
#        # getint() and getboolean() also do this for their respective types
#        SetConfig_SearchSettings(self, int(config.getfloat('Settings', 'photoSearch')))
#    except:
    print "Error:  ReadConfig"
#
##    # Notice that the next output does not interpolate '%(bar)s' or '%(baz)s'.
##    # This is because we are using a RawConfigParser().
##    if config.getboolean('Section1', 'bool'):
##        print config.get('Section1', 'foo')


def WriteConfig(self):
    print "Error:  ReadConfig"
#    config = ConfigParser.ConfigParser()
#
#    # When adding sections or items, add them in the reverse order of
#    # how you want them to be displayed in the actual file.
#    # In addition, please note that using RawConfigParser's and the raw
#    # mode of ConfigParser's respective set functions, you can assign
#    # non-string values to keys internally, but will receive an error
#    # when attempting to write to a file or when you get it in non-raw
#    # mode. SafeConfigParser does not allow such assignments to take place.
#    config.add_section('Settings')
#    config.set('Settings', 'photoSearch', self.core.SearchLoc)
#
#    # Writing our configuration file to 'example.cfg'
#    
#
#    with open('ansel-a.cfg', 'wb') as configfile:
#        config.write(configfile)


def SetConfig_SearchSettings(self, SearchLoc, Specific=""):
    if (SearchLoc==1):
        self.core.SearchLoc = 1
        self.core.imageDir = "/media/mmc1/DCIM/"
    else:
        self.core.SearchLoc = 0
        self.core.imageDir = "/home/user/MyDocs/DCIM/"

==> ansela_0.7-5.tar.gz: ansela-0.7/src/opt/anselA/core/config.py <==
from ConfigParser import ConfigParser
from core import *

def ReadConfig(self):
#    try:
#        configParser.ConfigParser()
#        config.read('ansel-a.cfg')
#
#        # getfloat() raises an exception if the value is not a float
#        # getint() and getboolean() also do this for their respective types
#        SetConfig_SearchSettings(self, int(config.getfloat('Settings', 'photoSearch')))
#    except:
    return
    #print "Error:  ReadConfig"
#
##    # Notice that the next output does not interpolate '%(bar)s' or '%(baz)s'.
##    # This is because we are using a RawConfigParser().
##    if config.getboolean('Section1', 'bool'):
##        print config.get('Section1', 'foo')


def WriteConfig(self):
    return
    #print "Error:  WriteConfig"
#    config = ConfigParser.ConfigParser()
#
#    # When adding sections or items, add them in the reverse order of
#    # how you want them to be displayed in the actual file.
#    # In addition, please note that using RawConfigParser's and the raw
#    # mode of ConfigParser's respective set functions, you can assign
#    # non-string values to keys internally, but will receive an error
#    # when attempting to write to a file or when you get it in non-raw
#    # mode. SafeConfigParser does not allow such assignments to take place.
#    config.add_section('Settings')
#    config.set('Settings', 'photoSearch', self.core.SearchLoc)
#
#    # Writing our configuration file to 'example.cfg'
#    
#
#    with open('ansel-a.cfg', 'wb') as configfile:
#        config.write(configfile)


def SetConfig_SearchSettings(self, SearchLoc, Specific=""):
    if (SearchLoc==1):
        self.core.SearchLoc = 1
        self.core.imageDir = "/media/mmc1/DCIM/"
    else:
        self.core.SearchLoc = 0
        self.core.imageDir = "/home/user/MyDocs/DCIM/"
